astscan

package
v0.1.171 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 2, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package astscan implements the `min ast` family of commands: scanning Go files, printing type declarations, and extracting context for a single function.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Fn

func Fn(target, path, typeFilter string) error

Fn extracts the context, references, and call sites for a function or method matching target, optionally filtered by receiver typeFilter.

func Scan

func Scan(path string) error

Scan prints top-level declarations of the Go file or directory at path, stripping function bodies.

func Types

func Types(path string) error

Types prints only type declarations of the Go file or directory at path.

Types

This section is empty.

Jump to