Documentation
¶
Overview ¶
Package astscan implements the `min ast` family of commands: scanning Go files, printing type declarations, and extracting context for a single function.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Fn ¶
Fn extracts the context, references, and call sites for a function or method matching target, optionally filtered by receiver typeFilter.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.